 /*
 *  file      : poche.h
 *  project   : zoomc
 *  with      : Gtk-2
 *
 *  copyright : (C) 2010 - 2011 by Claude Bulin
 *
 *  ZOOMC - GTK+ implementation of the GNU shell command
 *  GNU General Public License
 *
 *  This file is part of ZOOMC.
 * 
 *  ZOOMC is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  at your option) any later version.
 * 
 *  ZOOMC is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with ZOOMC.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef __poche_h__
#define __poche_h__ 1


#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gi18n.h>


// 
// poche.c
// poche_dir.c
// poche_save.c
// poche_txt.c
// 


typedef enum {
	_TYPE_IMAGE_ = 0,
	_TYPE_TEXT_,
	_TYPE_TEXT_TITLE_
} TYPE_IMAGE;

typedef struct {
	TYPE_IMAGE	TypeImage;				// IMAGE | TEXT
	
	// _TYPE_TEXT_
	// _TYPE_TEXT_TITLE_
	gchar		*Texte;					// 
	
	gchar		*FontName;				// 
	gint		SizeFontName;				// 
	gboolean	BoolFontBold;				// TRUE = BOLD,   FALSE = NORMAL
	gboolean	BoolFontItalic;				// TRUE = ITALIC, FALSE = NORMAL
	
	// _TYPE_IMAGE_
	GdkPixbuf	*Pixbuf;				// Adresse du PixBuf en traitement
	GdkPixbuf	*PixbufOriginal;			// Adresse du PixBuf original
	
	// VALUES
	gdouble		x0;					// Pos X
	gdouble		y0;					// Pos Y
	gint		image_width;				// Width
	gint		image_height;				// Height
	gdouble		XPointer;				// Position x de la souris lors du clic
	gdouble		YPointer;				// Position y de la souris lors du clic
	gboolean	BoolIsSelected;				// TRUE = selected with mouse cursor
	gboolean	BoolStructRemove;			// TRUE = STRUCT IS REMOVE | FALSE = ACTIVE
	gboolean	BoolFlipVertical;			// TRUE = Force flip Vertical
	gboolean	BoolFlipHorizontal;			// TRUE = Force flip Horizontal
} IMAGE;

typedef enum {
	IMG_HAUT_GAUCHE = 0,					// 
	IMG_HAUT,						// 
	IMG_HAUT_DROIT,						// 
	IMG_DROIT,						// 
	IMG_BAS_DROIT,						// 
	IMG_BAS,						// 
	IMG_BAS_GAUCHE,						// 
	IMG_GAUCHE,						// 
	IMG_MOVE,						// 
	IMG_SIZE,						// For size tab HANDLE_MOVE []
	IMG_NONE						// NO IMAGE SELECTED
} IMG_CORNER;

typedef struct {

	GdkRectangle	zone[ IMG_SIZE ];			// Les IMG_SIZE coordonnees de saisie de l'image
								// EX:
								// 	zone [ IMG_HAUT ] . x
								// 	zone [ IMG_HAUT ] . y
								// 	zone [ IMG_HAUT ] . width
								// 	zone [ IMG_HAUT ] . height
} HANDLE_MOVE;

typedef struct {
								// UNE STRUCTURE PAR FICHIER IMAGE
	gchar		*name_img;				// Nom du fichier image original
	gchar		*name_png;				// Nom du fichier PNG
	GtkWidget	*togglebutton;				// Adresse du bouton
	GtkWidget	*image;					// Adresse de l'image
	gboolean	BoolStructRemove;			// TRUE = STRUCT IS REMOVE | FALSE = ACTIVE
} GLIST_POCHETTE;

typedef struct {
	GtkWidget	*AdrDrawingarea;			// Adresse de la surface
	gboolean	BoolScaleAdjust;			// TRUE = ajustement de l'echelle avec la surface de la fentre
	cairo_surface_t	*image;					// Adresse de l'image
	gdouble		scale;					// Pourcentage de surface de l'image
	gdouble		x0;					// Pos X
	gdouble		y0;					// Pos Y
	gint		image_width;				// Width
	gint		image_height;				// Height
	GList		*ListImage;				// Pointeur de structure IMAGE pour AdrDrawingarea
	gboolean	BoolEventButtonPress;			// TRUE == BOUTON SOURIS PRESSED
	IMAGE		*GetImage;				// Adresse de l'image en selection
	IMG_CORNER	ImgCorner;				// See IMG_CORNER
	GtkWidget	*Adr_viewport_image_preview;		// Adresse viewport
	GtkWidget	*Adr_table;				// Adresse table contenu dans le viewport
	GList		*glist;					// Contient les structures GLIST_POCHETTE
	GtkWidget	*AdrTextview;				// Adresse textview
	gboolean	BoolSaveToFile;				// TRUE si sauvegarde vers fichier
	HANDLE_MOVE	HandleMove;				// Les coordonnees de saisie de l'image
} VIEW;

extern	VIEW view;

#define SIZE_IMAGE_VIEWPORT	80
#define SIZE_IMAGE_ADD		80
#define SCALE_MIN		0.60
#define MIN_SIZE_IMAGE		20	

#define MM(x)(((gdouble)x * 72.0) / 25.4 )

typedef struct {
	gchar	*PathLoadImg;
	gchar	*PathSaveImg;
	gchar	*PathPochette;
} CONFIG;

extern CONFIG	Config;

// 
// POCHE.C
// 
IMAGE	*poche_add_to_glist( gchar *PathNameFile, gdouble x, gdouble y, gboolean p_BoolScale, TYPE_IMAGE p_TypeImage );
IMAGE	*poche_get_struct_selected_is_txt( void );
void	poche_set_selected_flag_image( IMAGE *p_Image );
void	poche_set_selected_first_image( IMAGE *p_Image );
void	poche_set_selected_down_image( IMAGE *p_Image );
void	poche_set_selected_last_image( IMAGE *p_Image );
void	poche_add_img_file( GSList *p_list );
void	poche_remove_ListImage( void );
void	poche_remove_image( void );
void	poche_set_texte_title( gchar *p_str );
void	poche_paint( cairo_surface_t *cs );
void	poche_set_size_request( void );
void	poche_set_flag_buttons (void );
gboolean PocheTxt_get_is_bold( void );
gboolean PocheTxt_get_is_italic( void );
// 
// POCHE_DIR.C
// 
void	pochedir_add_img_file( GSList *p_list );
void	pochedir_remove_GlistPochette( void );
void	pochedir_table_add_images( void );
void	pochedir_make_glist (gchar *filename);
void	pochedir_destroy_image( GLIST_POCHETTE *gl );
// 
// POCHE_TXT.C
// 
void	PocheTxt_set_text_to_textview( IMAGE *p_Image );
gchar	*PocheTxt_get_ptr_entry_img_web( void );
gchar	*PocheTxt_get_ptr_entry_name_file_to_save( void );
// 
// POCHE_WEB.C
// 
void	pocheweb_get (void);

#endif

